@@ -1,10 +1,10 @@
-from . import Instrument
+from src.husamfinance.Instrument import Instrument
 from copy import deepcopy
 import talib
 
-class InstrumentTalib(Instrument.Instrument):
+class InstrumentTalib(Instrument):
 	def __init__(self,name):
-		Instrument.Instrument.__init__(self,name)
+		Instrument.__init__(self,name)
 
 	# OVERLAP FUNCTIONS
 
