@@ -1,13 +1,13 @@
-from . import InstrumentTalib
+from src.husamfinance.InstrumentTalib import InstrumentTalib
 from copy import deepcopy
 import talib
 import pandas as pd
 import numpy as np
-from . import InstrumentSignal
+from src.husamfinance.InstrumentSignal import InstrumentSignal
 
-class InstrumentTalibAdvanced(InstrumentTalib.InstrumentTalib):
+class InstrumentTalibAdvanced(InstrumentTalib):
 	def __init__(self,name):
-		InstrumentTalib.InstrumentTalib.__init__(self,name)
+		InstrumentTalib.__init__(self,name)
 		self.signals = pd.DataFrame(columns=['Signal Type','Status'])
 
 	def __str__(self):
@@ -17,13 +17,13 @@ class InstrumentTalibAdvanced(InstrumentTalib.InstrumentTalib):
 		return self.signals
 
 	def getBuyCount(self):
-		return self.signals["Status"].value_counts()[InstrumentSignal.InstrumentSignal.BUY]
+		return self.signals["Status"].value_counts()[InstrumentSignal.BUY]
 
 	def getSellCount(self):
-		return self.signals["Status"].value_counts()[InstrumentSignal.InstrumentSignal.SELL]
+		return self.signals["Status"].value_counts()[InstrumentSignal.SELL]
 
 	def getNeutralCount(self):
-		return self.signals["Status"].value_counts()[InstrumentSignal.InstrumentSignal.NEUTRAL]
+		return self.signals["Status"].value_counts()[InstrumentSignal.NEUTRAL]
 
 	def getSignals(self):
 		return self.signals
@@ -47,13 +47,13 @@ class InstrumentTalibAdvanced(InstrumentTalib.InstrumentTalib):
 			self.appendBB(14)
 
 		if self.getColumn("Close")[-1] < self.getColumn("BBLower")[-1]:
-			self.addSignal("BB" , InstrumentSignal.InstrumentSignal.BUY)
+			self.addSignal("BB" , InstrumentSignal.BUY)
 		elif self.getColumn("Close")[-1] > self.getColumn("BBUpper")[-1]:
-			self.addSignal("BB" , InstrumentSignal.InstrumentSignal.SELL)
+			self.addSignal("BB" , InstrumentSignal.SELL)
 		elif self.getColumn("Close")[-1] > self.getColumn("BBLower")[-1] and self.getColumn("Close")[-1] < self.getColumn("BBUpper")[-1]:
-			self.addSignal("BB" , InstrumentSignal.InstrumentSignal.NEUTRAL)
+			self.addSignal("BB" , InstrumentSignal.NEUTRAL)
 		else:
-			self.addSignal("BB" , InstrumentSignal.InstrumentSignal.NULL)
+			self.addSignal("BB" , InstrumentSignal.NULL)
 
 	def HT_signal(self):
 		pass
@@ -62,26 +62,26 @@ class InstrumentTalibAdvanced(InstrumentTalib.InstrumentTalib):
 			self.appendKAMA(14)		
 
 		if self.trendline("KAMA") > 0:
-			self.addSignal("KAMA" , InstrumentSignal.InstrumentSignal.BUY)
+			self.addSignal("KAMA" , InstrumentSignal.BUY)
 		elif self.trendline("KAMA") < 0:
-			self.addSignal("KAMA" , InstrumentSignal.InstrumentSignal.SELL)
+			self.addSignal("KAMA" , InstrumentSignal.SELL)
 		elif self.trendline("KAMA") == 0:
-			self.addSignal("KAMA" , InstrumentSignal.InstrumentSignal.NEUTRAL)
+			self.addSignal("KAMA" , InstrumentSignal.NEUTRAL)
 		else:
-			self.addSignal("KAMA" , InstrumentSignal.InstrumentSignal.NULL)
+			self.addSignal("KAMA" , InstrumentSignal.NULL)
 
 	def SAR_signal(self):
 		if "SAR" not in self.getData():
 			self.appendSAR()
 
 		if self.getColumn("SAR")[-1] < self.getColumn("Close")[-1]:
-			self.addSignal("SAR" , InstrumentSignal.InstrumentSignal.BUY)
+			self.addSignal("SAR" , InstrumentSignal.BUY)
 		elif self.getColumn("SAR")[-1] > self.getColumn("Close")[-1]:
-			self.addSignal("SAR" , InstrumentSignal.InstrumentSignal.SELL)
+			self.addSignal("SAR" , InstrumentSignal.SELL)
 		elif self.getColumn("SAR")[-1] == self.getColumn("Close")[-1]:
-			self.addSignal("SAR" , InstrumentSignal.InstrumentSignal.NEUTRAL)
+			self.addSignal("SAR" , InstrumentSignal.NEUTRAL)
 		else:
-			self.addSignal("SAR" , InstrumentSignal.InstrumentSignal.NULL)
+			self.addSignal("SAR" , InstrumentSignal.NULL)
 
 
 	def RSI_signal(self):
@@ -89,38 +89,38 @@ class InstrumentTalibAdvanced(InstrumentTalib.InstrumentTalib):
 			self.appendRSI(14)
 
 		if self.getColumn("RSI")[-1] <= 30 :
-			self.addSignal("RSI" , InstrumentSignal.InstrumentSignal.BUY)
+			self.addSignal("RSI" , InstrumentSignal.BUY)
 		elif self.getColumn("RSI")[-1] >= 70:
-			self.addSignal("RSI" , InstrumentSignal.InstrumentSignal.SELL)
+			self.addSignal("RSI" , InstrumentSignal.SELL)
 		elif self.getColumn("RSI")[-1] > 30 and self.getColumn("RSI")[-1] < 70:
-			self.addSignal("RSI" , InstrumentSignal.InstrumentSignal.NEUTRAL)
+			self.addSignal("RSI" , InstrumentSignal.NEUTRAL)
 		else:
-			self.addSignal("RSI" , InstrumentSignal.InstrumentSignal.NULL)
+			self.addSignal("RSI" , InstrumentSignal.NULL)
 
 	def MACD_signal(self):
 		if "MACD" not in self.getData():
 			self.appendMACD()
 
 		if self.getColumn("MACD_Hist")[-1] > 0:
-			self.addSignal("MACD",InstrumentSignal.InstrumentSignal.BUY)
+			self.addSignal("MACD",InstrumentSignal.BUY)
 		elif self.getColumn("MACD_Hist")[-1] < 0:
-			self.addSignal("MACD",InstrumentSignal.InstrumentSignal.SELL)
+			self.addSignal("MACD",InstrumentSignal.SELL)
 		elif self.getColumn("MACD_Hist")[-1] == 0:
-			self.addSignal("MACD",InstrumentSignal.InstrumentSignal.SELL)
+			self.addSignal("MACD",InstrumentSignal.SELL)
 		else:
-			self.addSignal("MACD" , InstrumentSignal.InstrumentSignal.NULL)
+			self.addSignal("MACD" , InstrumentSignal.NULL)
 
 	def ADX_signal(self):
 		if "ADX" not in self.getData():
 			self.appendADX(14)
 
 		if self.getColumn("ADX")[-1] > 25 :
-			self.addSignal("ADX" , InstrumentSignal.InstrumentSignal.BUY)
+			self.addSignal("ADX" , InstrumentSignal.BUY)
 		elif self.getColumn("ADX")[-1] < 20 :
-			self.addSignal("ADX" , InstrumentSignal.InstrumentSignal.SELL)
+			self.addSignal("ADX" , InstrumentSignal.SELL)
 		elif self.getColumn("ADX")[-1] < 25 and self.getColumn("ADX")[-1] > 20:
-			self.addSignal("ADX" , InstrumentSignal.InstrumentSignal.NEUTRAL)
+			self.addSignal("ADX" , InstrumentSignal.NEUTRAL)
 		else:
-			self.addSignal("ADX" , InstrumentSignal.InstrumentSignal.NULL)
+			self.addSignal("ADX" , InstrumentSignal.NULL)
 
 
